@@ -18,15 +18,13 @@
 #' \code{\link{simmr_mcmc}}.
 #' @param to_combine The names of exactly two sources. These should match the
 #' names given to \code{\link{simmr_load}}.
-#' @param new_source_name A name to give to the new combined source
+#' @param new_source_name A name to give to the new combined source.
 #' @return A new \code{simmr_output} object
 #' @author Andrew Parnell <andrew.parnell@@mu.ie>
 #' @seealso See \code{\link{simmr_mcmc}} and the associated vignette for
 #' examples.
 #' @examples
 #' \dontrun{
-#' # Data set 1: 10 obs on 2 isos, 4 sources, with tefs and concdep
-#'
 #' # The data
 #' data(geese_data)
 #'
@@ -71,8 +69,8 @@
 #' plot(simmr_1_out, type = "matrix")
 #'
 #' simmr_out_combine <- combine_sources(simmr_1_out,
-#'   to_combine = c("Source A", "Source D"),
-#'   new_source_name = "Source A+D"
+#'   to_combine = c("U.lactuca", "Enteromorpha"),
+#'   new_source_name = "U.lac+Ent"
 #' )
 #' plot(simmr_out_combine$input)
 #' plot(simmr_out_combine, type = "boxplot", title = "simmr output: combined sources")
@@ -91,20 +89,19 @@ combine_sources.simmr_output <- function(simmr_out,
   # A posteriori combining of sources
 
   # Check only two sources to be combined
-  if (length(to_combine) != 2) {
-    stop("Currently only two sources can be combined")
-  }
-
-  # # Check class
-  # if (class(simmr_out) != 'simmr_output')
-  #   stop("Only objects of class simmr_output can be run through this function")
+  assert_character(to_combine,
+    any.missing = FALSE,
+    all.missing = FALSE,
+    len = 2,
+    unique = TRUE
+  )
+  # Check that to_combine is in the list of sources
+  assert_true(all(to_combine %in% simmr_out$input$source_names))
 
   # Find which columns to combine by number
   to_combine_cols <- sort(match(to_combine, simmr_out$input$source_names))
-  if (any(is.na(to_combine_cols))) {
-    stop("1 or more source names not found")
-  }
 
+  # Create a new object
   simmr_new_out <- simmr_out
 
   # 1 combine the chosen source means
